Integration Test Docker Environment
===================================

This project provides a command line interface and a Python API layer to
start a test environment with an `Exasol
Docker-DB <https://hub.docker.com/r/exasol/docker-db>`_. Both start an
Exasol Docker-DB container, but the API Layer has extended functionality
and also can start an associated test container for whose content the
client is responsible.

Documentation
-------------

`Documentation for the current main branch <https://exasol.github.io/integration-test-docker-environment/main>`_ is hosted on the Github Pages of this project.
`Here <https://exasol.github.io/integration-test-docker-environment>`_  is a list of documentations for previous releases.
